@@ -1,7 +1,15 @@
 import requests
 import json
 
-def create(userID, uploadType, shot, resourceId, filePath, volumeName):
+def create( 
+        userID, 
+        uploadType, 
+        shot, 
+        resourceId, 
+        filePath, 
+        volumeName, 
+        resourceName
+    ):
     url = "http://sdt-api.qcc.svc.cluster.local"
     url_path = f"{url}/qcc/job"
 
@@ -15,7 +23,8 @@ def create(userID, uploadType, shot, resourceId, filePath, volumeName):
         "shot": shot,
         "resourceId": resourceId,
         "filePath": filePath,
-        "volumeName": volumeName
+        "volumeName": volumeName,
+        "resourceName": resourceName
     })
 
     response = requests.post(f"{url_path}", headers=headers, data=data) 
@@ -24,7 +33,8 @@ def create(userID, uploadType, shot, resourceId, filePath, volumeName):
 
     return response.text
 
-def getList(url):
+def getList():
+    url = "http://sdt-api.qcc.svc.cluster.local"
     url_path = f"{url}/qcc/jobs"
 
     # params = {
